@@ -55,9 +55,6 @@ ds9_shape_defs = dict(circle=wcs_shape(CoordOdd, CoordEven, Distance),
                       text=wcs_shape(CoordOdd, CoordEven)
                       )
 
-
-
-
 class RegionParser(RegionPusher):
 
     def __init__(self):
@@ -135,8 +132,6 @@ class RegionParser(RegionPusher):
 
             self.flush()
 
-
-
     def convert_attr(self, l):
         global_attr = [], {}
 
@@ -148,7 +143,10 @@ class RegionParser(RegionPusher):
                     if len(kv) == 1:
                         global_attr[0].append(kv[0])
                     elif len(kv) == 2:
-                        global_attr[1][kv[0]] = kv[1]
+                        if kv[0] == 'tag':
+                            global_attr[1].setdefault(kv[0],set()).add(kv[1])
+                        else:
+                            global_attr[1][kv[0]] = kv[1]
 
             elif isinstance(l1, Shape):
                 if c1:
@@ -168,9 +166,8 @@ class RegionParser(RegionPusher):
             else:
                 yield l1, c1
 
-
     @staticmethod
-    def sky_to_image(l, header):
+    def sky_to_image(l, header, rot_wrt_axis=1):
 
         try:
             header["NAXIS"]
@@ -205,14 +202,17 @@ class RegionParser(RegionPusher):
                 xy0 = None
 
                 cl1, fl1 = cl[:n1], fl[:n1]
-                cl10, xy0 = convert_to_imagecoord(cl1, fl1, wcs_proj, sky_to_sky, xy0)
+                cl10, xy0 = convert_to_imagecoord(cl1, fl1, wcs_proj,
+                                sky_to_sky, xy0, rot_wrt_axis=rot_wrt_axis)
 
                 nn2 = len(cl)-(len(fl) - n2)
                 cl2, fl2 = cl[n1:nn2], fl[n1:n2]
-                cl20, xy0 = convert_to_imagecoord(cl2, fl2, wcs_proj, sky_to_sky, xy0)
+                cl20, xy0 = convert_to_imagecoord(cl2, fl2, wcs_proj,
+                                sky_to_sky, xy0, rot_wrt_axis=rot_wrt_axis)
 
                 cl3, fl3 = cl[nn2:], fl[n2:]
-                cl30, xy0 = convert_to_imagecoord(cl3, fl3, wcs_proj, sky_to_sky, xy0)
+                cl30, xy0 = convert_to_imagecoord(cl3, fl3, wcs_proj,
+                                sky_to_sky, xy0, rot_wrt_axis=rot_wrt_axis)
 
                 new_cl = cl10 + cl20 + cl30
 
@@ -227,7 +227,7 @@ class RegionParser(RegionPusher):
 
                 if pc is None:
                     raise RuntimeError("Physical coordinate is not known.")
-                
+
                 cl = l1.coord_list
                 fl = ds9_shape_defs[l1.name].args_list
 
@@ -243,12 +243,14 @@ class RegionParser(RegionPusher):
 
                 cl1, fl1 = cl[:n1], fl[:n1]
                 cl10 = convert_physical_to_imagecoord(cl1, fl1, pc)
-                #cl10, xy0 = convert_to_imagecoord(cl1, fl1, wcs_proj, sky_to_sky, xy0)
+                #cl10, xy0 = convert_to_imagecoord(cl1, fl1, wcs_proj,
+                #                sky_to_sky, xy0, rot_wrt_axis=rot_wrt_axis)
 
                 nn2 = len(cl)-(len(fl) - n2)
                 cl2, fl2 = cl[n1:nn2], fl[n1:n2]
                 cl20 = convert_physical_to_imagecoord(cl2, fl2, pc)
-                #cl20, xy0 = convert_to_imagecoord(cl2, fl2, wcs_proj, sky_to_sky, xy0)
+                #cl20, xy0 = convert_to_imagecoord(cl2, fl2, wcs_proj,
+                #                sky_to_sky, xy0, rot_wrt_axis=rot_wrt_axis)
 
                 cl3, fl3 = cl[nn2:], fl[n2:]
                 cl30 = convert_physical_to_imagecoord(cl3, fl3, pc)
@@ -265,7 +267,6 @@ class RegionParser(RegionPusher):
             else:
                 yield l1, c1
 
-
     def filter_shape(self, sss):
         return [s1[0] for s1 in sss if isinstance(s1[0], Shape)]
 
@@ -289,7 +290,6 @@ def test_regionLine():
                   "rotbox",
                   "ellipse"]
 
-
     rp = RegionParser()
 
     for s, n in zip(test_string_1, test_names):
@@ -310,7 +310,6 @@ def test_comment():
 
     assert c == "comment2"
 
-
 def test_global():
     s = 'global color=green font="helvetica 10 normal" select=1 highlite=1 edit=1 move=1 delete=1 include=1 fixed=0 source'
 
